Learn R Programming

clarabel (version 0.11.2)

ClarabelSolver: A persistent Clarabel solver that can be reused across R calls.

Description

A persistent Clarabel solver that can be reused across R calls.

Usage

ClarabelSolver

Arguments

Format

An object of class clarabel::ClarabelSolver__bundle (inherits from savvy_clarabel__sealed) of length 1.