solver_is_update_allowed: Check if data updates are allowed on a persistent solver

View source: R/clarabel.R

solver_is_update_allowedR Documentation

Check if data updates are allowed on a persistent solver

Description

Returns FALSE if presolve, chordal decomposition or input_sparse_dropzeros has actually restructured this problem, which prevents data updates. Enabling one of those settings is not by itself enough to prevent updates; the transformation has to have taken place.

Usage

solver_is_update_allowed(solver)

Arguments

solver

a ClarabelSolver object created by clarabel_solver()

Value

logical scalar

See Also

clarabel_solver(), solver_update()

Examples

## Not run: 
solver_is_update_allowed(s)  # FALSE if the problem was restructured

## End(Not run)

clarabel documentation built on Aug. 23, 2026, 9:09 a.m.